summaryrefslogtreecommitdiff
path: root/tests/src/JIT/Performance/CodeQuality/Roslyn/CscBench.cs
diff options
context:
space:
mode:
Diffstat (limited to 'tests/src/JIT/Performance/CodeQuality/Roslyn/CscBench.cs')
-rw-r--r--tests/src/JIT/Performance/CodeQuality/Roslyn/CscBench.cs6
1 files changed, 3 insertions, 3 deletions
diff --git a/tests/src/JIT/Performance/CodeQuality/Roslyn/CscBench.cs b/tests/src/JIT/Performance/CodeQuality/Roslyn/CscBench.cs
index 92e132a327..e3337d115b 100644
--- a/tests/src/JIT/Performance/CodeQuality/Roslyn/CscBench.cs
+++ b/tests/src/JIT/Performance/CodeQuality/Roslyn/CscBench.cs
@@ -32,14 +32,14 @@ public static class CscBench
{
string CoreRoot = System.Environment.GetEnvironmentVariable("CORE_ROOT");
if (CoreRoot == null) { return false; }
- // Some CoreCLR packages have mscorlib.ni.dll only
- string nicorlib = Path.Combine(CoreRoot, "mscorlib.ni.dll");
+ // Some CoreCLR packages have System.Private.CoreLib.ni.dll only
+ string nicorlib = Path.Combine(CoreRoot, "System.Private.CoreLib.ni.dll");
if(File.Exists(nicorlib))
{
MscorlibPath = nicorlib;
return true;
}
- MscorlibPath = Path.Combine(CoreRoot, "mscorlib.dll");
+ MscorlibPath = Path.Combine(CoreRoot, "System.Private.CoreLib.dll");
return File.Exists(MscorlibPath);
}